#[non_exhaustive]pub enum StorefrontEvent {
OrderPlaced(OrderPlaced),
PaymentCaptured(PaymentCaptured),
RefundIssued(RefundIssued),
}Expand description
One event in the storefront stream, tagged by type in the encoded
payload (order_placed, payment_captured, refund_issued).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
OrderPlaced(OrderPlaced)
A customer placed an order.
PaymentCaptured(PaymentCaptured)
The payment for an order that was already placed came through.
RefundIssued(RefundIssued)
Part or all of a captured payment was refunded.
Implementations